marktools.attach_stem_tremolos_to_notes_and_chords_in_expr
==========================================================

.. autofunction:: abjad.tools.marktools.attach_stem_tremolos_to_notes_and_chords_in_expr.attach_stem_tremolos_to_notes_and_chords_in_expr
